.. _utilities:

=========
Utilities
=========

.. module:: sisl.utils
.. currentmodule:: sisl

Various helper classes and functions that make using `sisl` easier.


.. toctree::
   :maxdepth: 2

   utilities.shape
   utilities.misc


